# Changelog

<!--next-version-placeholder-->

## v10.11.1 (2021-06-28)
### Performance
* Avoid excessive loops ([#93](https://github.com/eyeonus/Trade-Dangerous/issues/93)) ([`f457db5`](https://github.com/eyeonus/Trade-Dangerous/commit/f457db5c9a6b46ce3610d993ff629d2a579e7ce8))

## v10.11.0 (2021-06-22)
### Feature
* Add switch to filter Odyssey Settlements ['--odyssey'|'--od']. ([`396d9f0`](https://github.com/eyeonus/Trade-Dangerous/commit/396d9f0876bcb2c1c4cf7ecb7e164c5139df5c8c))

## v10.10.0 (2021-03-26)
### Feature
* Allow for capacities above 1500 ([`76537b9`](https://github.com/eyeonus/Trade-Dangerous/commit/76537b9d84fc55994970f55f3cf39649c9c6bc5f))

## v10.9.8 (2021-02-05)
### Fix
* Update the build semantic, you jerk ([`8ca4e39`](https://github.com/eyeonus/Trade-Dangerous/commit/8ca4e392f7949e106636a1fee90a0d381b8a03e0))

## v10.9.7 (2021-02-05)
### Fix
* Add 'VOID OPAL' to corrections ([`f208023`](https://github.com/eyeonus/Trade-Dangerous/commit/f20802319a503f569d836c8d46ca7231779f5024))

## v10.9.6 (2021-01-18)
### Fix
* Edmc_batch_plug Path issues ([#83](https://github.com/eyeonus/Trade-Dangerous/issues/83)) ([`ef06684`](https://github.com/eyeonus/Trade-Dangerous/commit/ef06684e0534d1d969658e9b55f3a752c502475e))

## v10.9.5 (2021-01-09)
### Fix
* MaxGainPerTon shouldn't be set by default. ([`00c558c`](https://github.com/eyeonus/Trade-Dangerous/commit/00c558cf7f31fb82deb4ca176b43ca16db130559))

## v10.9.4 (2020-12-19)
### Fix
* Galactic Travel Guides are not deleted, just rare. ([`b20b9d0`](https://github.com/eyeonus/Trade-Dangerous/commit/b20b9d0abbcf4fb1d371715bc47da2e625a2cb23))

## v10.9.3 (2020-12-16)
### Fix
* Hopefully actually fix Travis this time. ([`970d721`](https://github.com/eyeonus/Trade-Dangerous/commit/970d721c2b512fff096f4bc76c15716f35a03633))

## v10.9.2 (2020-12-16)
### Fix
* Make Travis work again. ([`13addad`](https://github.com/eyeonus/Trade-Dangerous/commit/13addad48d2bb5f58b7e5c09c0ebdd5eedd74bd0))

## v10.9.1 (2020-12-16)
### Fix
* Ensure folder exists before attempting to write file ([`2de883f`](https://github.com/eyeonus/Trade-Dangerous/commit/2de883f62b1460c28da006d972da6225a9bd882f))
